@@ -26,29 +26,28 @@ DirichletDistribution <- R6::R6Class(
     #' @return An object of class \code{DirichletDistribution}. 
     initialize = function(alpha) {
       # check alpha parameter
-      if (length(alpha) < 2) {
-        rlang::abort(
-          "'alpha' must have at least 2 elements", 
-          class="alpha_unsupported"
+      abortifnot(length(alpha) >= 2L,
+        message = "'alpha' must have at least 2 elements", 
+        class = "alpha_unsupported"
+      )
+      vapply(alpha, FUN.VALUE = TRUE, FUN=function(x) {
+        abortifnot(!is.na(x),
+          message = "All elements of 'alpha' must be defined",
+          class = "alpha_not_defined"
         )
-      }
-      sapply(alpha, FUN=function(x) {
-        if (is.na(x)) {
-          rlang::abort("All elements of 'alpha' must be defined",
-                       class="alpha_not_defined")
-        }
-        if (!is.numeric(x)) {
-          rlang::abort("Argument 'alpha' must be a numeric vector",
-                       class="alpha_not_numeric")
-        }
-        if (x<=0) {
-          rlang::abort("Elements of 'alpha' must be > 0",
-                       class="alpha_unsupported")
-        }
+        abortifnot(is.numeric(x),
+          message = "Argument 'alpha' must be a numeric vector",
+          class = "alpha_not_numeric"
+        )
+        abortifnot(x > 0.0,
+          message = "Elements of 'alpha' must be > 0",
+          class = "alpha_unsupported"
+        )
+        return(TRUE)
       })
       private$alpha <- alpha
       # create subclass object and check parameter
-      super$initialize("Dir", K=length(alpha))
+      super$initialize("Dir", K = length(alpha))
       # set random sample to mean
       self$sample(TRUE)
       # return Dirichlet distribution object
@@ -58,7 +57,7 @@ DirichletDistribution <- R6::R6Class(
     #' @description Accessor function for the name of the distribution.
     #' @return Distribution name as character string.
     distribution = function() {
-      rv <- paste('Dir(', paste(private$alpha, collapse=','), ')', sep='')
+      rv <- paste0("Dir(", paste(private$alpha, collapse = ","), ")")
       return(rv)
     },
     
@@ -73,10 +72,10 @@ DirichletDistribution <- R6::R6Class(
     #' @details Undefined if any alpha is \eqn{\le 1}.
     #' @return Mode as a vector of length \code{K}.
     mode = function() {
-      rv <- rep(as.numeric(NA), times=private$K)
-      if (all(private$alpha > 1)) {
+      rv <- rep(NA_real_, times = private$K)
+      if (all(private$alpha > 1.0)) {
         alpha0 <- sum(private$alpha)
-        rv <- (private$alpha - 1) / (alpha0 - private$K)
+        rv <- (private$alpha - 1.0) / (alpha0 - private$K)
       }
       return(rv)
     },
@@ -92,36 +91,37 @@ DirichletDistribution <- R6::R6Class(
     #' are labelled with quantiles and columns with the dimension (1, 2, etc).
     quantile = function(probs) {
       # test argument
-      sapply(probs, FUN=function(x) {
-        if (is.na(x)) {
-          rlang::abort("All elements of 'probs' must be defined",
-                       class="probs_not_defined")
-        }
-        if (!is.numeric(x)) {
-          rlang::abort("Argument 'probs' must be a numeric vector",
-                       class="probs_not_numeric")
-        }
-        if (x<0 || x>1) {
-          rlang::abort("Elements of 'probs' must be in range[0,1]",
-                       class="probs_out_of_range")
-        }
+      vapply(probs, FUN.VALUE = TRUE, FUN=function(x) {
+        abortifnot(!is.na(x),
+          message = "All elements of 'probs' must be defined",
+          class = "probs_not_defined"
+        )
+        abortifnot(is.numeric(x),
+          message = "Argument 'probs' must be a numeric vector",
+          class = "probs_not_numeric"
+        )
+        abortifnot(x >= 0.0 && x <= 1.0,
+          message = "Elements of 'probs' must be in range[0,1]",
+          class = "probs_out_of_range"
+        )
+        return(TRUE)
       })
       # create output object
       rv <- matrix(
-        rep(as.numeric(NA), times=length(probs)*private$K),
+        rep(NA_real_, times = length(probs) * private$K),
         nrow = length(probs), 
         ncol = private$K,
-        dimnames = list(probs, seq(1:private$K))
+        dimnames = list(probs, seq_len(private$K))
       )
       # populate it
       alpha0 <- sum(private$alpha)
-      for (k in 1:private$K) {
+      for (k in seq_len(private$K)) {
         q <- stats::qbeta(
           probs, 
           shape1 = private$alpha[k], 
           shape2 = alpha0-private$alpha[k]
         )
-        rv[,k] <- q
+        rv[, k] <- q
       }
       return(rv)      
     },
@@ -130,13 +130,14 @@ DirichletDistribution <- R6::R6Class(
     #' @return A positive definite symmetric matrix of size \code{K} by 
     #' \code{K}.
     varcov = function() {
-      VC <- matrix(data=as.numeric(NA), nrow=private$K, ncol=private$K)
+      VC <- matrix(data = NA_real_, nrow = private$K, ncol = private$K)
       alpha0 <- sum(private$alpha)
       alphabar <- private$alpha / alpha0
-      for (i in 1:private$K) {
-        for (j in 1:private$K) {
-          VC[i,j] <- ifelse(i==j,alphabar[i],0) - (alphabar[i]*alphabar[j])
-          VC[i,j] <- VC[i,j] / (alpha0 + 1)
+      for (i in seq_len(private$K)) {
+        for (j in seq_len(private$K)) {
+          VC[[i,j]] <- ifelse(i == j, alphabar[[i]], 0L) -
+                       (alphabar[[i]] * alphabar[[j]])
+          VC[[i,j]] <- VC[[i,j]] / (alpha0 + 1L)
         }
       }
       return(VC)
@@ -146,11 +147,11 @@ DirichletDistribution <- R6::R6Class(
     #' @param expected If TRUE, sets the next value retrieved by a call to
     #' \code{r()} to be the mean of the distribution.
     #' @return Void; sample is retrieved with call to \code{r()}.
-    sample = function(expected=FALSE) {
-      if (!expected){
+    sample = function(expected = FALSE) {
+      if (!expected) {
         # sample from gamma distributions
-        y <- sapply(1:private$K, FUN=function(i) {
-          stats::rgamma(n=1, shape=private$alpha[i], rate=1)
+        y <- vapply(seq_len(private$K), FUN.VALUE = 0.5, FUN=function(i) {
+          stats::rgamma(n = 1L, shape=private$alpha[[i]], rate = 1.0)
         })
         # normalize and hold
         private$.r <- y / sum(y)
