@@ -2,8 +2,16 @@
 
 test_that("incorrect source and target are rejected", {
   n1 <- Node$new()
-  expect_error(e <- Arrow$new(42, n1), class="non-Node_endpoint")
-  expect_error(e <- Arrow$new(n1, 42), class="non-Node_endpoint")
+  expect_error(e <- Arrow$new(42L, n1), class="non-Node_endpoint")
+  expect_error(e <- Arrow$new(n1, 42L), class="non-Node_endpoint")
+})
+
+test_that("argument name matching supports old names", {
+  ns <- Node$new()
+  nt <- Node$new()
+  expect_silent(Arrow$new(source = ns, target = nt, label = "x"))
+  expect_silent(Arrow$new(source = ns, target_node = nt, label = "x"))
+  expect_silent(Arrow$new(source_node = ns, target = nt, label = "x"))
 })
 
 test_that("incorrect labels are rejected", {
@@ -18,7 +26,7 @@ test_that("arrow is defined correctly", {
   expect_silent(a <- Arrow$new(n1, n2, "a1"))
   expect_identical(n1, a$source())
   expect_identical(n2, a$target())
-  expect_equal(a$label(), "a1")
+  expect_identical(a$label(), "a1")
 })
 
 test_that("base edge object is defined correctly", {
@@ -26,8 +34,6 @@ test_that("base edge object is defined correctly", {
   n2 <- Node$new()
   expect_silent(a <- Arrow$new(n1, n2, "a1"))
   V <- a$endpoints()
-  expect_identical(n1, V[[1]])
-  expect_identical(n2, V[[2]])
+  expect_identical(n1, V[[1L]])
+  expect_identical(n2, V[[2L]])
 })
-
-
