@@ -5,7 +5,7 @@ test_that("missing state names are rejected", {
 })
 
 test_that("non-character state names are rejected", {
-  expect_error(MarkovState$new(name=42), class="non-string_state_name")
+  expect_error(MarkovState$new(name = 42L), class="non-string_state_name")
 })
 
 test_that("invalid annual costs are rejected", {
@@ -17,11 +17,11 @@ test_that("invalid annual costs are rejected", {
 
 test_that("invalid utilities are rejected", {
   expect_error(
-    MarkovState$new(name = "Futile", utility = list(42)),
+    MarkovState$new(name = "Futile", utility = list(42L)),
     class = "invalid_utility"
   )
   expect_error(
-    MarkovState$new(name = "Futile", utility = 2),
+    MarkovState$new(name = "Futile", utility = 2.0),
     class = "invalid_utility")
 })
 
@@ -32,20 +32,20 @@ test_that("names are set and got", {
 })
 
 test_that("costs are set and got", {
-  s <- MarkovState$new("S1", cost=42)
-  expect_equal(s$cost(), 42)
+  s <- MarkovState$new("S1", cost = 42.0)
+  expect_identical(s$cost(), 42.0)
 })
 
 test_that("utilties are set and got", {
-  s <- MarkovState$new("S1", utility=0.5)
-  expect_equal(s$utility(), 0.5)
+  s <- MarkovState$new("S1", utility = 0.5)
+  expect_identical(s$utility(), 0.5)
 })
 
 # tests of costs and utilities that are ModVars
 test_that("state cost and utility ModVars are recognised", {
   # create model variables
-  c.dis <- GammaModVar$new("Cost", "GBP", shape = 10000, scale = 1/10)
-  u.dis <- BetaModVar$new("Utility", "U", alpha = 10, beta = 10) 
+  c.dis <- GammaModVar$new("Cost", "GBP", shape = 10000.0, scale = 1.0/10.0)
+  u.dis <- BetaModVar$new("Utility", "U", alpha = 10L, beta = 10L) 
   # create states
   expect_silent(
     MarkovState$new(name = "Disabled", cost = c.dis)
@@ -56,11 +56,11 @@ test_that("state cost and utility ModVars are recognised", {
 })
 
 test_that("ModVar state utilities whose values exceed 1 cause warnings", {
-  u.beta <- BetaModVar$new("Utility", "U", alpha=10, beta=10) 
-  u.vw <- ExprModVar$new("vwell", "U", rlang::quo(2+u.beta))
+  u.beta <- BetaModVar$new("Utility", "U", alpha = 10L, beta = 10L) 
+  u.vw <- ExprModVar$new("vwell", "U", rlang::quo(2L + u.beta))
   u.beta$set("random")
   expect_silent(
-    s.vw <- MarkovState$new(name="Very Well", utility=u.vw)
+    s.vw <- MarkovState$new(name="Very Well", utility = u.vw)
   )
   expect_silent(
     u <- s.vw$utility()
@@ -68,20 +68,20 @@ test_that("ModVar state utilities whose values exceed 1 cause warnings", {
 })
 
 test_that("ModVars are identified and returned", {
-  fortytwo <- ConstModVar$new("fortytwo", "GBP", 42)
-  poorly <- BetaModVar$new("poorly", "U", alpha=10, beta=40)
+  fortytwo <- ConstModVar$new("fortytwo", "GBP", 42L)
+  poorly <- BetaModVar$new("poorly", "U", alpha = 10L, beta = 40L)
   # one modvar
-  s <- MarkovState$new("Ill", cost=fortytwo, utility=0.2)
+  s <- MarkovState$new("Ill", cost = fortytwo, utility = 0.2)
   mv <- s$modvars()
-  expect_equal(length(mv),1)
+  expect_length(mv, 1L)
   # two modvars
   s <- MarkovState$new("Ill", cost=fortytwo, utility=poorly)
   mv <- s$modvars()
-  expect_length(mv,2)
-  d <- sapply(mv, function(v) {
+  expect_length(mv, 2L)
+  d <- vapply(mv, FUN.VALUE = "x", FUN = function(v) {
     return(v$description())
   })
   expect_setequal(d, c("fortytwo", "poorly"))
-  expect_equal(s$cost(), 42)     # mean
-  expect_equal(s$utility(), 0.2) # mean
+  expect_identical(s$cost(), 42.0)     # mean
+  expect_identical(s$utility(), 0.2) # mean
 })
