@@ -1,10 +1,8 @@
-
-
 test_that("incorrect label types are rejected", {
   expect_silent(n1 <- Node$new("n1"))
   expect_identical(n1$label(), "n1")
-  expect_error(Node$new(42), class="non-string_label")
-  expect_error(Node$new(TRUE), class="non-string_label")
+  expect_error(Node$new(42L), class = "non-string_label")
+  expect_error(Node$new(TRUE), class = "non-string_label")
 })
 
 test_that("node type is returned", {
